# Converter

**Converter** 
converter is a python module that converts data size, the module has a class containing some methods to convert a value from bytes to megabytes as well as other data sizes.

